"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var __1 = require("../..");
var connected_component_1 = require("../renderer/canvas/connected_component");
var is_tooltip_visible_1 = require("../state/selectors/is_tooltip_visible");
var tooltip_1 = require("../state/selectors/tooltip");
var tooltip_2 = require("../../../components/tooltip");
var on_element_click_caller_1 = require("./selectors/on_element_click_caller");
var on_element_over_caller_1 = require("./selectors/on_element_over_caller");
var on_element_out_caller_1 = require("./selectors/on_element_out_caller");
var goal_spec_1 = require("./selectors/goal_spec");
var EMPTY_MAP = new Map();
var EMPTY_LEGEND_LIST = [];
var EMPTY_LEGEND_ITEM_LIST = [];
var GoalState = (function () {
    function GoalState() {
        this.chartType = __1.ChartTypes.Goal;
        this.onElementClickCaller = on_element_click_caller_1.createOnElementClickCaller();
        this.onElementOverCaller = on_element_over_caller_1.createOnElementOverCaller();
        this.onElementOutCaller = on_element_out_caller_1.createOnElementOutCaller();
    }
    GoalState.prototype.isInitialized = function (globalState) {
        return globalState.specsInitialized && goal_spec_1.getSpecOrNull(globalState) !== null;
    };
    GoalState.prototype.isBrushAvailable = function () {
        return false;
    };
    GoalState.prototype.isBrushing = function () {
        return false;
    };
    GoalState.prototype.isChartEmpty = function () {
        return false;
    };
    GoalState.prototype.getLegendItems = function () {
        return EMPTY_LEGEND_LIST;
    };
    GoalState.prototype.getLegendItemsLabels = function () {
        return EMPTY_LEGEND_ITEM_LIST;
    };
    GoalState.prototype.getLegendExtraValues = function () {
        return EMPTY_MAP;
    };
    GoalState.prototype.chartRenderer = function (containerRef) {
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(tooltip_2.Tooltip, { getChartContainerRef: containerRef }),
            react_1.default.createElement(connected_component_1.Goal, null)));
    };
    GoalState.prototype.getPointerCursor = function () {
        return 'default';
    };
    GoalState.prototype.isTooltipVisible = function (globalState) {
        return is_tooltip_visible_1.isTooltipVisibleSelector(globalState);
    };
    GoalState.prototype.getTooltipInfo = function (globalState) {
        return tooltip_1.getTooltipInfoSelector(globalState);
    };
    GoalState.prototype.getTooltipAnchor = function (state) {
        var position = state.interactions.pointer.current.position;
        return {
            isRotated: false,
            x1: position.x,
            y1: position.y,
        };
    };
    GoalState.prototype.eventCallbacks = function (globalState) {
        this.onElementOverCaller(globalState);
        this.onElementOutCaller(globalState);
        this.onElementClickCaller(globalState);
    };
    return GoalState;
}());
exports.GoalState = GoalState;
//# sourceMappingURL=chart_state.js.map