"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
var specs_1 = require("../../utils/specs");
var commons_1 = require("../../../../utils/commons");
var utils_1 = require("../../state/utils");
var types_1 = require("../../../../scales/types");
var utils_2 = require("../../state/utils");
exports.DEFAULT_LINE_OVERFLOW = 0;
function computeYDomainLineAnnotationDimensions(dataValues, yScale, chartRotation, axisPosition, chartDimensions, lineColor, marker, markerDimension) {
    if (markerDimension === void 0) { markerDimension = { width: 0, height: 0 }; }
    var chartHeight = chartDimensions.height;
    var chartWidth = chartDimensions.width;
    var isHorizontalChartRotation = utils_1.isHorizontalRotation(chartRotation);
    var anchorPosition = axisPosition === null ? (isHorizontalChartRotation ? commons_1.Position.Left : commons_1.Position.Bottom) : axisPosition;
    var lineProps = [];
    dataValues.forEach(function (datum) {
        var dataValue = datum.dataValue;
        if (dataValue === null || dataValue === undefined || dataValue === '') {
            return;
        }
        var annotationValueYposition = yScale.scale(dataValue);
        if (annotationValueYposition === null) {
            return;
        }
        var _a = __read(yScale.domain, 2), domainStart = _a[0], domainEnd = _a[1];
        if (dataValue < domainStart || dataValue > domainEnd) {
            return;
        }
        var anchor = {
            position: anchorPosition,
            top: 0,
            left: 0,
        };
        var markerPosition = { top: 0, left: 0 };
        var linePathPoints = {
            start: { x1: 0, y1: 0 },
            end: { x2: 0, y2: 0 },
        };
        if (isHorizontalChartRotation) {
            if (anchorPosition === commons_1.Position.Left) {
                anchor.left = 0;
                markerPosition.left = -markerDimension.width;
                linePathPoints.start.x1 = 0;
                linePathPoints.end.x2 = chartWidth;
            }
            else {
                anchor.left = chartWidth;
                markerPosition.left = chartWidth;
                linePathPoints.start.x1 = chartWidth;
                linePathPoints.end.x2 = 0;
            }
            if (chartRotation === 0) {
                anchor.top = annotationValueYposition;
                markerPosition.top = annotationValueYposition - markerDimension.height / 2;
            }
            else {
                anchor.top = chartHeight - annotationValueYposition;
                markerPosition.top = chartHeight - annotationValueYposition - markerDimension.height / 2;
            }
            linePathPoints.start.y1 = annotationValueYposition;
            linePathPoints.end.y2 = annotationValueYposition;
        }
        else {
            if (anchorPosition === commons_1.Position.Top) {
                anchor.top = 0;
                markerPosition.top = -markerDimension.height;
                linePathPoints.start.x1 = 0;
                linePathPoints.end.x2 = chartHeight;
            }
            else {
                anchor.top = chartHeight;
                markerPosition.top = chartHeight;
                linePathPoints.start.x1 = chartHeight;
                linePathPoints.end.x2 = 0;
            }
            if (chartRotation === -90) {
                anchor.left = annotationValueYposition;
                markerPosition.left = annotationValueYposition - markerDimension.width / 2;
            }
            else {
                anchor.left = chartWidth - annotationValueYposition;
                markerPosition.left = chartWidth - annotationValueYposition - markerDimension.width / 2;
            }
            linePathPoints.start.y1 = annotationValueYposition;
            linePathPoints.end.y2 = annotationValueYposition;
        }
        var annotationMarker = marker
            ? {
                icon: marker,
                color: lineColor,
                dimension: markerDimension,
                position: markerPosition,
            }
            : undefined;
        var lineProp = {
            anchor: anchor,
            linePathPoints: linePathPoints,
            marker: annotationMarker,
            details: {
                detailsText: datum.details,
                headerText: datum.header || dataValue.toString(),
            },
        };
        lineProps.push(lineProp);
    });
    return lineProps;
}
function computeXDomainLineAnnotationDimensions(dataValues, xScale, chartRotation, axisPosition, chartDimensions, lineColor, isHistogramMode, marker, markerDimension) {
    if (markerDimension === void 0) { markerDimension = { width: 0, height: 0 }; }
    var chartHeight = chartDimensions.height;
    var chartWidth = chartDimensions.width;
    var lineProps = [];
    var isHorizontalChartRotation = utils_1.isHorizontalRotation(chartRotation);
    var anchorPosition = axisPosition === null ? (isHorizontalChartRotation ? commons_1.Position.Bottom : commons_1.Position.Left) : axisPosition;
    dataValues.forEach(function (datum) {
        var dataValue = datum.dataValue;
        var annotationValueXposition = xScale.scale(dataValue);
        if (annotationValueXposition == null) {
            return;
        }
        if (types_1.isContinuousScale(xScale) && typeof dataValue === 'number') {
            var minDomain = xScale.domain[0];
            var maxDomain = isHistogramMode ? xScale.domain[1] + xScale.minInterval : xScale.domain[1];
            if (dataValue < minDomain || dataValue > maxDomain) {
                return;
            }
            if (isHistogramMode) {
                var offset = utils_2.computeXScaleOffset(xScale, true);
                var pureScaledValue = xScale.pureScale(dataValue);
                if (pureScaledValue == null) {
                    return;
                }
                annotationValueXposition = pureScaledValue - offset;
            }
            else {
                annotationValueXposition = annotationValueXposition + (xScale.bandwidth * xScale.totalBarsInCluster) / 2;
            }
        }
        else if (types_1.isBandScale(xScale)) {
            if (isHistogramMode) {
                var padding = (xScale.step - xScale.originalBandwidth) / 2;
                annotationValueXposition = annotationValueXposition - padding;
            }
            else {
                annotationValueXposition = annotationValueXposition + xScale.originalBandwidth / 2;
            }
        }
        else {
            return;
        }
        if (isNaN(annotationValueXposition) || annotationValueXposition == null) {
            return;
        }
        var markerPosition = { top: 0, left: 0 };
        var linePathPoints = {
            start: { x1: 0, y1: 0 },
            end: { x2: 0, y2: 0 },
        };
        var anchor = {
            position: anchorPosition,
            top: 0,
            left: 0,
        };
        if (isHorizontalChartRotation) {
            if (anchorPosition === commons_1.Position.Bottom) {
                linePathPoints.start.y1 = chartHeight;
                linePathPoints.end.y2 = 0;
                anchor.top = chartHeight;
                markerPosition.top = chartHeight;
            }
            else {
                linePathPoints.start.y1 = 0;
                linePathPoints.end.y2 = chartHeight;
                anchor.top = 0;
                markerPosition.top = 0 - markerDimension.height;
            }
            if (chartRotation === 0) {
                anchor.left = annotationValueXposition;
                markerPosition.left = annotationValueXposition - markerDimension.width / 2;
            }
            else {
                anchor.left = chartWidth - annotationValueXposition;
                markerPosition.left = chartWidth - annotationValueXposition - markerDimension.width / 2;
            }
            linePathPoints.start.x1 = annotationValueXposition;
            linePathPoints.end.x2 = annotationValueXposition;
        }
        else {
            if (anchorPosition === commons_1.Position.Left) {
                anchor.left = 0;
                markerPosition.left = -markerDimension.width;
                linePathPoints.start.x1 = annotationValueXposition;
                linePathPoints.end.x2 = annotationValueXposition;
            }
            else {
                anchor.left = chartWidth;
                markerPosition.left = chartWidth;
                linePathPoints.start.x1 = annotationValueXposition;
                linePathPoints.end.x2 = annotationValueXposition;
            }
            if (chartRotation === -90) {
                anchor.top = chartHeight - annotationValueXposition;
                markerPosition.top = chartHeight - annotationValueXposition - markerDimension.height / 2;
                linePathPoints.start.y1 = 0;
                linePathPoints.end.y2 = chartWidth;
            }
            else {
                anchor.top = annotationValueXposition;
                markerPosition.top = annotationValueXposition - markerDimension.height / 2;
                linePathPoints.start.y1 = 0;
                linePathPoints.end.y2 = chartWidth;
            }
        }
        var annotationMarker = marker
            ? {
                icon: marker,
                color: lineColor,
                dimension: markerDimension,
                position: markerPosition,
            }
            : undefined;
        var lineProp = {
            anchor: anchor,
            linePathPoints: linePathPoints,
            details: {
                detailsText: datum.details,
                headerText: datum.header || dataValue.toString(),
            },
            marker: annotationMarker,
        };
        lineProps.push(lineProp);
    });
    return lineProps;
}
function computeLineAnnotationDimensions(annotationSpec, chartDimensions, chartRotation, yScales, xScale, axisPosition, isHistogramMode) {
    var _a, _b, _c;
    var domainType = annotationSpec.domainType, dataValues = annotationSpec.dataValues, marker = annotationSpec.marker, markerDimensions = annotationSpec.markerDimensions, hideLines = annotationSpec.hideLines;
    if (hideLines) {
        return null;
    }
    var lineStyle = annotationSpec.style;
    var lineColor = (_c = (_b = (_a = lineStyle) === null || _a === void 0 ? void 0 : _a.line) === null || _b === void 0 ? void 0 : _b.stroke, (_c !== null && _c !== void 0 ? _c : 'red'));
    if (domainType === specs_1.AnnotationDomainTypes.XDomain) {
        return computeXDomainLineAnnotationDimensions(dataValues, xScale, chartRotation, axisPosition, chartDimensions, lineColor, isHistogramMode, marker, markerDimensions);
    }
    var groupId = annotationSpec.groupId;
    var yScale = yScales.get(groupId);
    if (!yScale) {
        return null;
    }
    return computeYDomainLineAnnotationDimensions(dataValues, yScale, chartRotation, axisPosition, chartDimensions, lineColor, marker, markerDimensions);
}
exports.computeLineAnnotationDimensions = computeLineAnnotationDimensions;
//# sourceMappingURL=dimensions.js.map