"use strict";
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
Object.defineProperty(exports, "__esModule", { value: true });
var specs_1 = require("../utils/specs");
var commons_1 = require("../../../utils/commons");
var tooltip_1 = require("./line/tooltip");
var tooltip_2 = require("./rect/tooltip");
function computeAnnotationTooltipState(cursorPosition, annotationDimensions, annotationSpecs, chartRotation, axesSpecs, chartDimensions) {
    var e_1, _a;
    var sortedSpecs = annotationSpecs
        .slice()
        .reverse()
        .sort(function (_a, _b) {
        var _c = _a.zIndex, a = _c === void 0 ? Number.MIN_SAFE_INTEGER : _c;
        var _d = _b.zIndex, b = _d === void 0 ? Number.MIN_SAFE_INTEGER : _d;
        return b - a;
    });
    try {
        for (var sortedSpecs_1 = __values(sortedSpecs), sortedSpecs_1_1 = sortedSpecs_1.next(); !sortedSpecs_1_1.done; sortedSpecs_1_1 = sortedSpecs_1.next()) {
            var spec = sortedSpecs_1_1.value;
            var annotationDimension = annotationDimensions.get(spec.id);
            if (spec.hideTooltips || !annotationDimension) {
                continue;
            }
            var groupId = spec.groupId;
            if (specs_1.isLineAnnotation(spec)) {
                if (spec.hideLines) {
                    continue;
                }
                var lineAnnotationTooltipState = tooltip_1.computeLineAnnotationTooltipState(cursorPosition, annotationDimension, groupId, spec.domainType, axesSpecs);
                if (lineAnnotationTooltipState.isVisible) {
                    return lineAnnotationTooltipState;
                }
            }
            else if (specs_1.isRectAnnotation(spec)) {
                var rectAnnotationTooltipState = tooltip_2.computeRectAnnotationTooltipState(cursorPosition, annotationDimension, chartRotation, chartDimensions, spec.renderTooltip);
                if (rectAnnotationTooltipState.isVisible) {
                    return rectAnnotationTooltipState;
                }
            }
        }
    }
    catch (e_1_1) { e_1 = { error: e_1_1 }; }
    finally {
        try {
            if (sortedSpecs_1_1 && !sortedSpecs_1_1.done && (_a = sortedSpecs_1.return)) _a.call(sortedSpecs_1);
        }
        finally { if (e_1) throw e_1.error; }
    }
    return null;
}
exports.computeAnnotationTooltipState = computeAnnotationTooltipState;
function getFinalAnnotationTooltipPosition(container, chartDimensions, tooltip, tooltipAnchor, portalWidth, padding) {
    if (padding === void 0) { padding = 10; }
    var left = 0;
    var anchor = commons_1.Position.Left;
    var annotationXOffset = window.pageXOffset + container.left + chartDimensions.left + tooltipAnchor.left;
    if (chartDimensions.left + tooltipAnchor.left + portalWidth + padding >= container.width) {
        left = annotationXOffset - portalWidth - padding;
        anchor = commons_1.Position.Right;
    }
    else {
        left = annotationXOffset + padding;
    }
    var top = window.pageYOffset + container.top + chartDimensions.top + tooltipAnchor.top;
    if (chartDimensions.top + tooltipAnchor.top + tooltip.height + padding >= container.height) {
        top -= tooltip.height + padding;
    }
    else {
        top += padding;
    }
    return {
        left: Math.round(left) + "px",
        top: Math.round(top) + "px",
        anchor: anchor,
    };
}
exports.getFinalAnnotationTooltipPosition = getFinalAnnotationTooltipPosition;
//# sourceMappingURL=tooltip.js.map