"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var specs_1 = require("../utils/specs");
var utils_1 = require("../state/utils");
var dimensions_1 = require("./line/dimensions");
var dimensions_2 = require("./rect/dimensions");
function getAnnotationAxis(axesSpecs, groupId, domainType, chartRotation) {
    var _a = utils_1.getAxesSpecForSpecId(axesSpecs, groupId), xAxis = _a.xAxis, yAxis = _a.yAxis;
    var isHorizontalRotated = utils_1.isHorizontalRotation(chartRotation);
    var isXDomainAnnotation = isXDomain(domainType);
    var annotationAxis = isXDomainAnnotation ? xAxis : yAxis;
    var rotatedAnnotation = isHorizontalRotated ? annotationAxis : isXDomainAnnotation ? yAxis : xAxis;
    return rotatedAnnotation ? rotatedAnnotation.position : null;
}
exports.getAnnotationAxis = getAnnotationAxis;
function isXDomain(domainType) {
    return domainType === specs_1.AnnotationDomainTypes.XDomain;
}
exports.isXDomain = isXDomain;
function getRotatedCursor(cursorPosition, chartDimensions, chartRotation) {
    var x = cursorPosition.x, y = cursorPosition.y;
    var height = chartDimensions.height, width = chartDimensions.width;
    switch (chartRotation) {
        case 0:
            return { x: x, y: y };
        case 90:
            return { x: y, y: width - x };
        case -90:
            return { x: height - y, y: x };
        case 180:
            return { x: width - x, y: height - y };
    }
}
exports.getRotatedCursor = getRotatedCursor;
function computeAnnotationDimensions(annotations, chartDimensions, chartRotation, yScales, xScale, axesSpecs, isHistogramModeEnabled) {
    var annotationDimensions = new Map();
    annotations.forEach(function (annotationSpec) {
        var id = annotationSpec.id;
        if (specs_1.isLineAnnotation(annotationSpec)) {
            var groupId = annotationSpec.groupId, domainType = annotationSpec.domainType;
            var annotationAxisPosition = getAnnotationAxis(axesSpecs, groupId, domainType, chartRotation);
            var dimensions = dimensions_1.computeLineAnnotationDimensions(annotationSpec, chartDimensions, chartRotation, yScales, xScale, annotationAxisPosition, isHistogramModeEnabled);
            if (dimensions) {
                annotationDimensions.set(id, dimensions);
            }
        }
        else if (specs_1.isRectAnnotation(annotationSpec)) {
            var dimensions = dimensions_2.computeRectAnnotationDimensions(annotationSpec, yScales, xScale, isHistogramModeEnabled);
            if (dimensions) {
                annotationDimensions.set(id, dimensions);
            }
        }
    });
    return annotationDimensions;
}
exports.computeAnnotationDimensions = computeAnnotationDimensions;
//# sourceMappingURL=utils.js.map