"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseTimeParts = void 0;

var _moment = _interopRequireDefault(require("moment"));

var _datemath = _interopRequireDefault(require("@elastic/datemath"));

var _predicate = require("../../../../services/predicate");

var _relative_options = require("../relative_options");

var _date_modes = require("../date_modes");

/**
 * This function returns time value, time unit and time tense for a given time string.
 * For example: for `now-40m` it will parse output as time value to `40`
 * time unit to `m` and time unit to `last`.
 * If given a datetime string it will return a default value.
 * If the given string is in the format such as `now/d` it will parse the string to moment object
 * and find the time value, time unit and time tense using moment
 * This function accepts two strings start and end time. I the start value is now then it uses
 * the end value to parse.
 *
 * @param {string} start start time
 * @param {string} start end time
 * @returns {object} time value, time unit and time tense
 */
var LAST = 'last';
var NEXT = 'next';

var isNow = function isNow(value) {
  return value === _date_modes.DATE_MODES.NOW;
};

var parseTimeParts = function parseTimeParts(start, end) {
  var results = {
    timeValueDefault: 15,
    timeUnitsDefault: 'm',
    timeTenseDefault: LAST
  };
  var value = isNow(start) ? end : start;
  var matches = (0, _predicate.isString)(value) && value.match(/now(([-+])(\d+)([smhdwMy])(\/[smhdwMy])?)?/);

  if (!matches) {
    return results;
  }

  var operator = matches[2];
  var timeValue = matches[3];
  var timeUnitsDefault = matches[4];

  if (timeValue && timeUnitsDefault && operator) {
    var timeValueDefault = parseInt(timeValue, 10);
    var timeTenseDefault = operator === '+' ? NEXT : LAST;
    return {
      timeValueDefault: timeValueDefault,
      timeUnitsDefault: timeUnitsDefault,
      timeTenseDefault: timeTenseDefault
    };
  }

  var duration = _moment.default.duration((0, _moment.default)().diff(_datemath.default.parse(value)));

  var unitOp = '';

  for (var i = 0; i < _relative_options.relativeUnitsFromLargestToSmallest.length; i++) {
    var as = duration.as(_relative_options.relativeUnitsFromLargestToSmallest[i]);
    if (as < 0) unitOp = '+';

    if (Math.abs(as) > 1) {
      results.timeValueDefault = Math.round(Math.abs(as));
      results.timeUnitsDefault = _relative_options.relativeUnitsFromLargestToSmallest[i];
      results.timeTenseDefault = unitOp === '+' ? NEXT : LAST;
      break;
    }
  }

  return results;
};

exports.parseTimeParts = parseTimeParts;